# ozi-spec CHANGELOG
## 0.5.1 (2024-07-11)


### 🐛 Fixed Bugs

* update version — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`158212b`](https://github.com/OZI-Project/ozi-spec/commit/158212baf2061b55a99c556bc0f1862498ba16ac))

## 0.5.0 (2024-07-07)


### Feature


* feat(src.py SrcTemplate): add ``templates``, ``subprojects`` and modified ``ci_provider`` to be a dictionary of tuples — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6dbd31c`](https://github.com/OZI-Project/ozi-spec/commit/6dbd31c9f0a1053ed0b544c954cc71c20bf150b3))


### 🐛 Fixed Bugs

* update commit parser templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`4975a1c`](https://github.com/OZI-Project/ozi-spec/commit/4975a1cc3e3e10b38cae41e5584b92649505eb4e))


### Performance


* perf: run black — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`a2f0bc8`](https://github.com/OZI-Project/ozi-spec/commit/a2f0bc8356204624cbbf719f363272ef7531e1ed))

* perf: OZI-Project/draft@0.3.4 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e747e9b`](https://github.com/OZI-Project/ozi-spec/commit/e747e9b1c5caeb5c54c51f66a30eab7b57850878))

* perf: OZI-Project/publish@0.1.7 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`c224b07`](https://github.com/OZI-Project/ozi-spec/commit/c224b078da4060195d040dec97abb58ca12fb057))

## 0.4.1 (2024-07-01)


### 🐛 Fixed Bugs

* individual file license/copyright header corrected to Unlicense
([`74ff29c`](https://github.com/OZI-Project/ozi-spec/commit/74ff29cc0ea4e991cddffd1da6f553eb1fbb40a8))

* doc and download link metadata — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`8c849f6`](https://github.com/OZI-Project/ozi-spec/commit/8c849f692a566ff65499712f38e3b10da86b1dc8))

## 0.4.0 (2024-07-01)


### 👷 Updated Continuous Integration

* add 0.x branch pattern — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`5d606c8`](https://github.com/OZI-Project/ozi-spec/commit/5d606c850a9316b1b9f7ecf0cc7c9897b82f6fa1))


### Feature


* feat: tag OZI 1.14
([`b6cb028`](https://github.com/OZI-Project/ozi-spec/commit/b6cb0285901d95512e7545c06edd7f2c539c4125))


### Unknown


* Update requirements.in — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`a0bcce3`](https://github.com/OZI-Project/ozi-spec/commit/a0bcce34cf6ba9abfd1bdc0685ae9d6c62a7c742))

## 0.3.0 (2024-07-01)


### Feature


* feat: init from OZI 1.13.31 spec submodule source
([`434d1db`](https://github.com/OZI-Project/ozi-spec/commit/434d1db4aff6652cd9b88002d18c4d14f55cbd0d))
